@@ -34,14 +34,28 @@ def test_basics(paramsurvey_init):
     assert [r.slept == duration for r in results], 'everyone slept '+str(duration)
     assert len(results) == len(psets), 'one return for each pset'
     assert len(results.missing) == 0
+    assert results.progress.total == len(psets)
+    assert results.progress.finished == len(psets)
+    assert results.progress.failures == 0
+    assert results.progress.exceptions == 0
     assert isinstance(results.verbose, int)
-    # XXX check stats
+
+    df_as_listdict = results.to_listdict()
+    assert len(df_as_listdict) == len(results)
+    assert [d['slept'] == duration for d in df_as_listdict]
+
+    results.stats.print_histograms()
 
     psets = psets[:ncores]
     start = time.time()
     results = paramsurvey.map(sleep_worker, psets, name='group_size 5', group_size=5)
     elapsed = time.time() - start
     assert elapsed > duration*3, 'must take at least {} time'.format(duration)
+    assert len(results) == len(psets)
+    assert results.progress.total == len(psets)
+    assert results.progress.finished == len(psets)
+    assert results.progress.failures == 0
+    assert results.progress.exceptions == 0
 
     assert [r.slept == duration for r in results], 'everyone slept '+str(duration)
     assert len(results) == len(psets), 'one return for each pset'
@@ -183,6 +197,26 @@ def test_wrapper_exception(capsys, paramsurvey_init):
     assert 'failures: 2' in captured.out or 'failures: 2' in captured.err
 
 
+def bad_user_function(pset, system_kwargs, user_kwargs, raw_stats):
+    return 3
+
+
+def test_bad_user_function(paramsurvey_init):
+    psets = [{'a': 1}, {'a': 2}]
+
+    results = paramsurvey.map(bad_user_function, psets, name='bad_user_function')
+
+    print(results.df)
+    print(results.missing)
+    print(results.stats)
+
+    assert len(results.missing) == 2
+    assert results.progress.total == 2
+    assert results.progress.finished == 0
+    assert results.progress.failures == 2
+    assert results.progress.exceptions == 2
+
+
 def test_toplevel(paramsurvey_init):
     assert paramsurvey.backend() == os.environ.get('PARAMSURVEY_BACKEND', paramsurvey.default_backend)
 
